package
Version:
v0.2.4
Opens a new window with list of versions in this module.
Published: Mar 31, 2026
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func RegisterBlueprints()
RegisterBlueprints registers the Company and User blueprints.
Call seedling.ResetRegistry() before this in tests to start fresh.
Company represents a company record.
User represents a user who belongs to a company.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.